package Google::Cloud::PubSub::V1::SubscriberClient;

use strict;
use warnings;

use Protobuf;
use Google::Api::Common;
use Google::Pubsub::V1::Schema;
use Google::Pubsub::V1::Pubsub;

our $VERSION = '0.02';
1; # End of Google::Cloud::PubSub::V1::SubscriberClient

__END__

=head1 NAME

Google::Cloud::PubSub::V1::SubscriberClient - Auto-generated Protocol Buffers schema container

=head1 DESCRIPTION

This is an auto-generated Protocol Buffers schema container module for Google Cloud Services.

=head1 SOURCE

Generated from the following Protocol Buffers schemas:

=over 4

=item * C<google/pubsub/v1/schema.proto>

=item * C<google/pubsub/v1/pubsub.proto>



=back

=head1 LICENSE AND COPYRIGHT

Copyright (C) 2026 Google LLC

This program is released under the Apache 2.0 license.

=cut
